@@ -6,7 +6,14 @@ from _pytest.config import (
     PytestPluginManager,
     create_terminal_writer,
 )
-from _pytest.fixtures import FixtureDef, FixtureRequest, SubRequest
+from _pytest.fixtures import (
+    FixtureDef,
+    FixtureManager,
+    FixtureRequest,
+    SubRequest,
+    get_direct_param_fixture_func,
+    getfixturemarker,
+)
 from _pytest.junitxml import LogXML
 from _pytest.mark import Mark
 from _pytest.nodes import Item, Node
