@@ -4,7 +4,7 @@ from allure_commons_test.report import AllureReport
 
 import pitest as pytest
 
-pytest_plugins = "pytester"
+pytest_plugins = 'pytester'
 
 
 class GlamorPytester:
@@ -14,11 +14,17 @@ class GlamorPytester:
 
     def runpytest(self, *args, **kwargs):
         result = self.pytester.runpytest(
-            "--alluredir", str(self.pytester.path), *args, **kwargs
+            '--alluredir', str(self.pytester.path), *args, **kwargs
         )
         self.allure_report = AllureReport(str(self.pytester.path))
         return result
 
+    def makepyfile(self, *args, **kwargs):
+        return self.pytester.makepyfile(*args, **kwargs)
+
+    def makeconftest(self, source: str):
+        return self.pytester.makeconftest(source)
+
 
 @pytest.fixture
 def glamor_pytester(pytester: pytest.Pytester):
